#ifndef GUIF_H
#define GUIF_H

#include "gui.h"

/* Fill out the structure below (except for filename). */
	
typedef struct {
	/* Application canvas that the file is being
		selected for the use of. */
	guiCanvasPtr from;

	/* Filename that should initially be selected. This can
		be a directory, in which case that directory will
		appear first with no file selected. If this is
		an empty string or a null pointer, then the current
		working directory will appear. If it is an
		individual file, then that file will be
		initially selected to in the directory listing. */
	char *initialFilename;

	/* Pattern that files must match to be displayed.
		The user can still manually enter filenames
		that do not match the filter, or change
		the filter. Example: *.gif|*.jpeg|*.jpg|*.png, or just * */
	char *filter;

	/* Window title. */
	char *title;

	/* Window label (inside the window). */
	char *label;

	/* If this is not null, a Help button will be displayed,
		and this function will be invoked when it is selected. 
		text will contain the name of the help button for
		compatibility with button action handlers. */
	void (*helpHandler) (char *text, void *clientData);

	/* This will be passed as the argument to the helpHandler
		function. */	
	void *helpClientData;

	/* If this is nonzero, the user is required to select
		a pre-existing file. */
	int mustExist;

	/* If the file selection succeeds, then guiFileSelect will set 
		this to point to an allocated string, which you must 
		free() after use. This will be set to a null
		pointer if guiFileCanceled is returned. */
	char *outputFilename;
} guiFileOptions, *guiFileOptionsPtr;

typedef enum {
	guiFileCanceled,
	guiFileExisting,
	guiFileNew
} guiFileResult;

guiFileResult guiFileSelect(guiFileOptionsPtr options);

#endif /* GUIF_H */

