#ifndef GUIL_H 
#define GUIL_H 1

#include "gui.h"

typedef struct {
	char **text;
	void **itemData;
	void *clientData;
	int rowsAllocated;
	int rowsTotal;
	int selected;
	int sorted;
	guiNativeHandle c;
	int clickWaiting;
	void (*actionHandler) (char *item, 
		void *itemData, void *clientData, int final);
} guiList, *guiListPtr;

guiSize guiListEstimate(int rows, int cols);

guiListPtr guiListCreate(guiCanvasPtr parent, int x, int y, int w, int h);

void guiListSetClientData(guiListPtr l, void *clientData);

void *guiListGetClientData(guiListPtr l);

int guiListGetRowsTotal(guiListPtr l);

void guiListDestroy(guiListPtr l);

void guiListSetSorted(guiListPtr l, int flag);

void guiListSetActionHandler(guiListPtr l,
	void (*actionHandler) (char *item, void *itemData, 
		void *clientData, int final));

void guiListAddItem(guiListPtr l, char *text, void *itemData);

void guiListInsertItem(guiListPtr l, int index, char *text, void *itemData);

void guiListRemoveItem(guiListPtr l, int index);

/* Both of these functions will scroll the display to the matching item.
	For guiListFindItemByText, if the list is sorted, then the display 
	will scroll to the closest match even if there is no exact match. 
	Both return guiNone if there is no exact match, or the index
	of the exact match. */

int guiListFindItemByText(guiListPtr l, char *text);

int guiListFindItemByClientData(guiListPtr l, void *clientData);

void guiListClear(guiListPtr l);

/* Sets the selected item. */

void guiListSelectItem(guiListPtr l, int index);

/* Returns the index of the selected item, or guiNone. */
	
int guiListGetSelectedItem(guiListPtr l);

/* Returns an ALLOCATED COPY of the text of the indicated item. 
	You MUST CALL free() on the returned string when
	you are finished with it. Otherwise the memory
	will be lost. */
	
char *guiListGetItemText(guiListPtr l, int index);

/* Retrieves the client data associated with the specified index. */

void *guiListGetItemClientData(guiListPtr l, int index);

/* The usual family of wrappers */

void guiListShow(guiListPtr l, int flag);

void guiListMove(guiListPtr l, int x, int y);

void guiListSetPhysicalSize(guiListPtr l, int w, int h);

guiSize guiListGetPhysicalSize(guiListPtr l);

extern guiFont guiListFont;

/* Color for the text. The background is guiDefaultBackgroundColor. */
extern guiColor guiListColor;

#endif /* GUIL_H */

