#ifndef GUIM_H
#define GUIM_H 1

/* A guiMenu object represents an entire bar of menus (but just one is a
	perfectly acceptable case). */

#include "gui.h"

typedef struct guiMenuItemStruct {
	char *label;
	void *clientData;
	void (*actionHandler) (char *text, void *clientData);
	int selected;
	guiKey hotkey;
	int hotkeyPos;
	struct guiMenuItemStruct *next;
	int active;
	int checked;
} guiMenuItem, *guiMenuItemPtr;

struct guiMenuStruct;

typedef struct guiMenuDataStruct {
	struct guiMenuStruct *bar;
	guiNativeHandle button;
	guiNativeHandle body;
	char *label;
	guiMenuItemPtr first;		
	int selected;
	guiKey hotkey;
	int hotkeyPos;
	struct guiMenuDataStruct *next;	
} guiMenuData, *guiMenuDataPtr;

typedef struct guiMenuStruct {
	guiMenuDataPtr first;
	guiNativeHandle c;
} guiMenu, *guiMenuPtr;

/* Useful *before* creating menu bars to estimate the size of a
	single button. */

guiSize guiMenuButtonEstimate(char *s);

/* Returns the size of the horizontal gap between 
	menu buttons on the bar. */

int guiMenuGapEstimate();

/* Creates the menu bar, with no menus present initially. */

guiMenuPtr guiMenuCreate(guiCanvasPtr parent, int x, int y);

/* Adds an individual menu. An & before a character in the label indicates 
	that the character should pop up the menu (if combined
	with the alt key). Example: &File */

guiMenuDataPtr guiMenuAdd(guiMenuPtr m, char *label);

/* Adds an item to an individual menu. An & before a character in the 
	item text indicates that the character following should select 
	that item if the menu was popped up from the keyboard. */

guiMenuItemPtr guiMenuAddItem(guiMenuDataPtr m, char *text,
	void *clientData, 
	void (*actionHandler) (char *text, void *clientData));

/* "Checks" or unchecks a menu item. */

void guiMenuItemSetCheck(guiMenuItemPtr p, int flag);

int guiMenuItemGetCheck(guiMenuItemPtr p);

/* Sets whether a menu item is active or inactive (grayed).
	True by default. */

void guiMenuItemSetActive(guiMenuItemPtr p, int flag);

/* Retrieves the active/inactive setting. */
int guiMenuItemGetActive(guiMenuItemPtr p);

/* Destroys the entire menu bar. */

void guiMenuDestroy(guiMenuPtr m);

/* Returns the dimensions of the bar. */

guiSize guiMenuGetPhysicalSize(guiMenuPtr m);

/* Shows the menu bar. */

void guiMenuShow(guiMenuPtr m, int flag);

/* Not fully initialized until either one of the
	estimate functions is used or a menu is created. */

extern guiFont guiMenuFont;

extern guiColor guiMenuBackgroundColor;

extern guiColor guiMenuHighlightColor;

extern guiColor guiMenuLabelColor;

#endif /* GUIM_H */

