#ifndef GUIXT_H
#define GUIXT_H 1

#include "gui.h"

typedef struct guiTextStruct {
	guiCanvasPtr c;
	char **text;
	int *colsAllocated;
	int *colsTotal;
	int rowsAllocated;
	int rowsTotal;
	int rowsTotalLast;
	/* Cursor */
	int row, col;
	/* Start of selection (ends at cursor) */
	int sRow, sCol;
	int wordWrap;
	int charsMax;
	int charsTotal;
	int colsMax;
	int multiline;
	int selection;
	int repaintAll;
	int readOnly;
	int rowWidest;
	int pixelWidest;
	int blinkOn;
	int active;
	void (*updateHandler) (struct guiTextStruct *t, void *clientData);
	void *clientData;
} guiText, *guiTextPtr;

typedef enum {
        guiTextSucceeded,
        guiTextNoMemory,
        guiTextFull
} guiTextResult;

/* Estimate the size for a single-line text area with the
	specified number of columns (visible). */

guiSize guiTextEstimateSingle(int cols);

/* Estimate the size for a multiple-line text area with the
	specified number of rows and columns (all of them visible). */

guiSize guiTextEstimateMultiple(int rows, int cols);

/* charsMax may be set to guiNone, in which case
	the text may grow as large as memory permits. */

guiTextPtr guiTextCreateSingle(guiCanvasPtr parent, int x, int y, 
	int w, int h, int charsMax);

/* colsMax may be set to guiNone, in which case
	a column can be as wide as desired. */

guiTextPtr guiTextCreateMultiple(guiCanvasPtr parent, int x, int y,
	int width, int height, int colsMax);

guiSize guiTextGetPhysicalSize(guiTextPtr t);

void guiTextTakeFocus(guiTextPtr t);

void guiTextSetPhysicalSize(guiTextPtr t, int w, int h);

void guiTextMove(guiTextPtr t, int x, int y);

void guiTextShow(guiTextPtr t, int flag);

void guiTextSetActive(guiTextPtr t, int active);

int guiTextGetActive(guiTextPtr t);

/* Call before inserting any text. Defaults to true if
	colsMax is not guiNone. */
void guiTextSetWordWrap(guiTextPtr t, int wordWrap);

void guiTextDestroy(guiTextPtr t);

void guiTextSet(guiTextPtr t, char *text, int textLen);

void guiTextSetReadOnly(guiTextPtr t, int readOnly);

/* Fetches an allocated copy, which must be deallocated by calling free() */
char *guiTextGet(guiTextPtr t);

/* Returns atoi() or atof() of the data, respectively, for convenience. */
int guiTextGetInt(guiTextPtr t);

double guiTextGetDouble(guiTextPtr t);

/* Fetches the length, not including a terminating null */
int guiTextGetLength(guiTextPtr t);

/* Fetches the text into a user-supplied buffer. If textSize is not null
	then it will be set to the number of bytes actually retrieved
	including the terminating null. */
void guiTextGetBuffer(guiTextPtr t, char *buf, int bufSize, int *textSize);

/* Sets a function to be invoked whenever the text changes.
	This function should return swiftly. The function will
	be passed a pointer to the text object and the user-specified
	data set in this call. */

void guiTextSetUpdateHandler(guiTextPtr t, 
	void (*updateHandler) (guiTextPtr t, void *clientData), 
	void *clientData);

extern guiFont guiTextFont;

extern guiColor guiTextColor;

extern guiColor guiTextSelectionColor;

#endif /* GUIXT_H */

